@@ -1,4 +1,4 @@
-# $Id: Listable.pm 1512 2010-11-16 23:45:05Z rvos $
+# $Id: Listable.pm 1593 2011-02-27 15:26:04Z rvos $
 package Bio::Phylo::Listable;
 use strict;
 use vars qw(@ISA);
@@ -1209,9 +1209,18 @@ defined there are also applicable here.
 
 =back
 
+=head1 CITATION
+
+If you use Bio::Phylo in published research, please cite it:
+
+B<Rutger A Vos>, B<Jason Caravas>, B<Klaas Hartmann>, B<Mark A Jensen>
+and B<Chase Miller>, 2011. Bio::Phylo - phyloinformatic analysis using Perl.
+I<BMC Bioinformatics> B<12>:63.
+L<http://dx.doi.org/10.1186/1471-2105-12-63>
+
 =head1 REVISION
 
- $Id: Listable.pm 1512 2010-11-16 23:45:05Z rvos $
+ $Id: Listable.pm 1593 2011-02-27 15:26:04Z rvos $
 
 =cut
 
