@@ -1,4 +1,4 @@
-# $Id: DOM.pm 1502 2010-11-16 19:48:45Z rvos $
+# $Id: DOM.pm 1593 2011-02-27 15:26:04Z rvos $
 package Bio::Phylo::NeXML::DOM;
 use strict;
 use Bio::Phylo ();
@@ -370,6 +370,15 @@ obtained from the C<Element> and C<Document> POD.
 The DOM creator abstract classes: L<Bio::Phylo::NeXML::DOM::Element>,
 L<Bio::Phylo::NeXML::DOM::Document>
 
+=head1 CITATION
+
+If you use Bio::Phylo in published research, please cite it:
+
+B<Rutger A Vos>, B<Jason Caravas>, B<Klaas Hartmann>, B<Mark A Jensen>
+and B<Chase Miller>, 2011. Bio::Phylo - phyloinformatic analysis using Perl.
+I<BMC Bioinformatics> B<12>:63.
+L<http://dx.doi.org/10.1186/1471-2105-12-63>
+
 =head1 AUTHOR
 
 Mark A. Jensen  (maj -at- fortinbras -dot- us), refactored by Rutger Vos
