@@ -1,4 +1,4 @@
-# $Id: Writable.pm 1586 2010-12-16 00:59:38Z rvos $
+# $Id: Writable.pm 1593 2011-02-27 15:26:04Z rvos $
 package Bio::Phylo::NeXML::Writable;
 use strict;
 use Bio::Phylo ();
@@ -859,9 +859,18 @@ Serializes object to JSON string
 
 Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>.
 
+=head1 CITATION
+
+If you use Bio::Phylo in published research, please cite it:
+
+B<Rutger A Vos>, B<Jason Caravas>, B<Klaas Hartmann>, B<Mark A Jensen>
+and B<Chase Miller>, 2011. Bio::Phylo - phyloinformatic analysis using Perl.
+I<BMC Bioinformatics> B<12>:63.
+L<http://dx.doi.org/10.1186/1471-2105-12-63>
+
 =head1 REVISION
 
- $Id: Writable.pm 1586 2010-12-16 00:59:38Z rvos $
+ $Id: Writable.pm 1593 2011-02-27 15:26:04Z rvos $
 
 =cut
 
