@@ -48,9 +48,18 @@ For more information about the nexml data standard, visit L<http://www.nexml.org
 
 =back
 
+=head1 CITATION
+
+If you use Bio::Phylo in published research, please cite it:
+
+B<Rutger A Vos>, B<Jason Caravas>, B<Klaas Hartmann>, B<Mark A Jensen>
+and B<Chase Miller>, 2011. Bio::Phylo - phyloinformatic analysis using Perl.
+I<BMC Bioinformatics> B<12>:63.
+L<http://dx.doi.org/10.1186/1471-2105-12-63>
+
 =head1 REVISION
 
- $Id: Nexml.pm 1524 2010-11-25 19:24:12Z rvos $
+ $Id: Nexml.pm 1593 2011-02-27 15:26:04Z rvos $
 
 =cut
 
