@@ -1,4 +1,4 @@
-# $Id: Nexus.pm 1524 2010-11-25 19:24:12Z rvos $
+# $Id: Nexus.pm 1593 2011-02-27 15:26:04Z rvos $
 package Bio::Phylo::Parsers::Nexus;
 use strict;
 use Bio::Phylo::Factory;
@@ -1039,7 +1039,7 @@ sub _end {
     $self->{'_translate'} = [];
     if ( uc $self->{'_previous'} eq ';' and $self->{'_trees'} ) {
         my $forest = $self->_current;
-        my $trees = parse( '-format' => 'newick', '-string' => $self->{'_trees'} );
+        my $trees = parse( '-format' => 'newick', '-string' => $self->{'_trees'}, '-as_project' => 0 );
         for my $tree ( @{ $trees->get_entities } ) {
         	$forest->insert($tree);
         }
@@ -1134,9 +1134,18 @@ Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>.
 
 =back
 
+=head1 CITATION
+
+If you use Bio::Phylo in published research, please cite it:
+
+B<Rutger A Vos>, B<Jason Caravas>, B<Klaas Hartmann>, B<Mark A Jensen>
+and B<Chase Miller>, 2011. Bio::Phylo - phyloinformatic analysis using Perl.
+I<BMC Bioinformatics> B<12>:63.
+L<http://dx.doi.org/10.1186/1471-2105-12-63>
+
 =head1 REVISION
 
- $Id: Nexus.pm 1524 2010-11-25 19:24:12Z rvos $
+ $Id: Nexus.pm 1593 2011-02-27 15:26:04Z rvos $
 
 =cut
 
